@@ -2,6 +2,6 @@
     Logic conditions
 """
 
-from ._not import Not
+from .not_ import Not
 from .all_of import AllOf
 from .any_of import AnyOf
